// FILE: ./assets/js/utilities/GeralCE_Utility.js
var GeralCE_Utility = function (General, ZhFilterPreferences, ZHPromise) {
    
    this.openFilter = function(widget){

        var promises = [];
        promises.push(ZhFilterPreferences.setOriginalFilter(widget.id));
        promises.push(ZhFilterPreferences.openFilterWidget(widget));
        ZHPromise.all(promises).then(function(rowSetFilter){
          //  this.setFilter(widget);
        }.bind(this)); 
    };
    
    this.openFilterFilial = function(widget) {
        this.setFieldsGerais(widget);
        var rowsToSet = {};
        this.getFilialLogada().then(function(success) {
            rowsToSet.CDFILIAL = success.dataset.filial[0].CDFILIAL;
            rowsToSet.NMFILIAL = success.dataset.filial[0].NMFILIAL;
            ZhFilterPreferences.openFilterWidget(widget, rowsToSet);
        });
    };
	
	this.getFilialLogada = function() {
        var filter = [
                {
                    "name": "CDFILIAL",
                    "operator": "=",
                    "value": "FILIAL_LOGADA"
                }
		    ];
        return General.callRestEngine('est#/crud/filial', 'FilterData', filter);
    };
    
    this.removerMascaras= function(row){
        if(!Util.isEmptyOrBlank(row.NRINSJURTRAN)){
            row.NRINSJURTRAN =row.NRINSJURTRAN.replace(/[^0-9]/g,'');
        }
        if(!Util.isEmptyOrBlank(row.NRTELETRAN)){
            row.NRTELETRAN =row.NRTELETRAN.replace(/[^0-9]/g,'');
        }
        if(!Util.isEmptyOrBlank(row.NRFAXTRAN)){
            row.NRFAXTRAN =row.NRFAXTRAN.replace(/[^0-9]/g,'');
        }
        if(!Util.isEmptyOrBlank(row.NRTELEXTRAN)){
            row.NRTELEXTRAN =row.NRTELEXTRAN.replace(/[^0-9]/g,'');
        }
        if(!Util.isEmptyOrBlank(row.NRCEPTRAN)){
           row.NRCEPTRAN =row.NRCEPTRAN.replace(/[^0-9]/g,'');
        }
        if(!Util.isEmptyOrBlank(row.NRCPF)){
           row.NRCPF =row.NRCPF.replace(/[^0-9]/g,'');
        }
    };
    
};

Configuration(function(ContextRegister){
    ContextRegister.register('GeralCE_Utility', GeralCE_Utility);
});

// FILE: ./assets/js/repositories/Ger01100_Transportadora_Repository.js
var Ger01100_Transportadora_Repository = function (restEngine) {
	this.saveTransportadora = function (row) {
		return restEngine.post('cadExp#/crud/transport_completa/save', {
			"requestType": "Row",
			"row": row
		});
	};

	this.findParceiro = function (row) {
		var filtro = [
			{
				"name": "NRINSCRICAOPARC",
				"operator": "=",
				"value": row.INSCRICAO
            }
        ];
		return restEngine.post('cadExp#/findParceiroCadExp', {
			"requestType": "FilterData",
			"filter": filtro
		});
	};
};

Configuration(function (ContextRegister) {
	ContextRegister.register('Ger01100_Transportadora_Repository', Ger01100_Transportadora_Repository);
});

// FILE: ./assets/js/services/Ger01100_Transportadora_Service.js
var Ger01100_Transportadora_Service = function (General,Ger01100_Transportadora_Repository) {

    this.validateNumeroDeInscricao = function(inputValue) {
        var inscricao = General.inscricaoFormat(inputValue);
        if(!inscricao.valid) {
            //build appropriated error messages
            inscricao.error = {};
            switch(inscricao.tipo.cod) {
                case 'J':
                    inscricao.error.msg = "CNPJ \"" + inscricao.value + "\" inválido!";
                    break;
                case 'F':
                    inscricao.error.msg = "CPF \"" + inscricao.value + "\" inválido!";
                    break;
                case null:
                    break;
                case 'I':
                /* falls through */
                default:
                    inscricao.error.msg = inscricao.tipo.desc + " \"" + inscricao.value + "\" inválida!";
            }
        }
        return inscricao;
    };

    this.salvarTransportadora = function(row){
        return Ger01100_Transportadora_Repository.saveTransportadora(row);
    };
    this.buscarParceiro = function(row){
        return Ger01100_Transportadora_Repository.findParceiro(row);

    };
    this.removerMascaras= function(row){
        if(row.NRINSJURTRAN){
            row.NRINSJURTRAN =row.NRINSJURTRAN.replace(/[^0-9]/g,'');
        }
        if(row.NRTELETRAN){
            row.NRTELETRAN =row.NRTELETRAN.replace(/[^0-9]/g,'');
        }
        if(row.NRFAXTRAN){
            row.NRFAXTRAN =row.NRFAXTRAN.replace(/[^0-9]/g,'');
        }
        if(row.NRTELEXTRAN){
            row.NRTELEXTRAN =row.NRTELEXTRAN.replace(/[^0-9]/g,'');
        }
        if(row.NRCEPTRAN){
           row.NRCEPTRAN =row.NRCEPTRAN.replace(/[^0-9]/g,'');
        }
    };


};

Configuration(function(ContextRegister){
    ContextRegister.register('Ger01100_Transportadora_Service', Ger01100_Transportadora_Service);
});

// FILE: ./assets/js/controllers/exp01300_veiculosController.js
function exp01300_veiculosController (ScreenService, General, GeralCE_Utility, templateManager){
    
    this.new = function(widget){
        widget.newRow();
    };
    
    this.calcularValorKmRodado = function (widget){
        
        var VRMANUMENSAL = widget.currentRow.VRMANUMENSAL;
        var VRKMMEDIAANO = widget.currentRow.VRKMMEDIAANO;
        var VRKMMEDLITRO = widget.currentRow.VRKMMEDLITRO;
        var VRMEDLTCOMB = widget.currentRow.VRMEDLTCOMB;
        
        if(((VRMANUMENSAL || VRMEDLTCOMB) > 0) && ((VRKMMEDIAANO && VRKMMEDLITRO) > 0)){
            
            var VRKMRODAVIAT = (((VRMANUMENSAL * 12) + ((VRKMMEDIAANO / VRKMMEDLITRO) * (VRMEDLTCOMB))) / VRKMMEDIAANO);
        
            widget.currentRow.VRKMRODAVIAT = VRKMRODAVIAT;
            
        }else {
            ScreenService.showMessage('Para fazer a operação, preencha os seguintes campos com valores positivos: Quilometragem Média Anual, Vr Médio Litro Combustível, Quilômetros por Litro (Média), Valor Manutenção Mensal');
            widget.currentRow.VRKMRODAVIAT = null;
        }
            
    };
    
    this.atualizaFields = function(){
        var widget = templateManager.container.getWidget('exp01300_veiculos');
        widget.__filterPopup.getField('CDVIATURA').reload();
        widget.__filterPopup.getField('NRPLACA').reload();
        widget.__filterPopup.getField('DSTIPOVEIC').reload();
    };
    
    this.salvar = function(){
        var widget = templateManager.container.getWidget('exp01300_veiculos');
        if(widget.isValid()){
            var data = widget.dataSource.data;
            var erro = 0;
            for(var i = 0; i < data.length; i++){
                if(widget.currentRow.CDVIATURA == data[i].CDVIATURA){
                    erro ++;
                }else if(widget.currentRow.NRPLACA == data[i].NRPLACA){
                    erro ++;
                }
            }
            if(erro > 1){
                ScreenService.showMessage('Impossível adicionar. Registro já existe.');
            }else{
                var placa = widget.currentRow.NRPLACA;
                var er = /[a-z]{3}-?\d{4}/gim;  
                er.lastIndex = 0;  
                var result = er.test(placa);
                if(result == true){
                    General.saveCrud(widget);
                }else{
                    ScreenService.showMessage("Número de placa inválido.");
                    widget.getField('NRPLACA').setValue('');
                    widget.getField('NRPLACA').reload();
                }
            }
            
        }    
    };

}

Configuration(function(ContextRegister){
    ContextRegister.register('exp01300_veiculosController', exp01300_veiculosController);
});

// FILE: ./assets/js/controllers/Ger01100_Transportadora_Controller.js
var Ger01100_Transportadora_Controller = function (ScreenService, General, GeralCE_Utility, templateManager, restEngine, localStorageEngine, Endereco, Ger01100_Transportadora_Service) {

	this.atualizaFields = function(){
		var widget = templateManager.container.getWidget('gridTransportadora');
		widget.getField('NMRAZSOCFORN').reload();
		widget.getField('NMTIPTRANS').reload();
	};
	
	this.newTransportadora = function(widget){
		General.newRow(widget);
		this.controlaVisibilidadeCampoPaisEstadoMunicipioBairro(widget.name);
	};
	
	this.setFieldsAddress = function (widgetName, fieldName) {
		//field = General.getFieldValue(fieldName,widgetName);
		//field = field.toString();
		//return field;
		return General.getFieldValue(fieldName, widgetName);
		//return templateManager.container.getWidget(widgetName).currentRow[fieldName] || '';
	};

	this.controlaVisibilidadeCampoPaisEstadoMunicipioBairro = function (nomeWidget) {
		var widget = templateManager.container.getWidget(nomeWidget);
		var pais = widget.getField('NMPAIS');
		var estado = widget.getField('NMESTADO');
		var municipio = widget.getField('NMMUNICIPIO');
		var bairro = widget.getField('NMBAIRTRAN');
		if (widget.currentRow.NMPAIS) {
			estado.readOnly = false;
			municipio.readOnly = true;
			bairro.readOnly = true;
			if (widget.currentRow.NMESTADO) {
				municipio.readOnly = false;
				bairro.readOnly = true;
				if (widget.currentRow.NMMUNICIPIO) {
					bairro.readOnly = false;
				} else {
					bairro.readOnly = true;
				}
			} else {
				municipio.readOnly = true;
				bairro.readOnly = true;
			}
		} else {
			estado.readOnly = true;
			municipio.readOnly = true;
			bairro.readOnly = true;
		}
	};

	this.controlaValorCampoPaisEstadoMunicipioBairro = function (nomeCampoAtual, nomeWidget) {
		var widget = templateManager.container.getWidget(nomeWidget);
		var pais = widget.getField('NMPAIS');
		var estado = widget.getField('NMESTADO');
		var municipio = widget.getField('NMMUNICIPIO');
		var bairro = widget.getField('NMBAIRTRAN');
		switch (nomeCampoAtual) {
		case 'Pais':
			estado.value('');
			municipio.value('');
			bairro.value('');
			break;
		case 'Estado':
			municipio.value('');
			bairro.value('');
			break;
		case 'Municipio':
			bairro.value('');
			break;
		default:
			break;
		}
	};

	this.recarregarCampo = function (nomeWidget, nomeCampo) {
		var widget = templateManager.container.getWidget(nomeWidget);
		widget.getField(nomeCampo).reload();
	};

	this.recarregarWidget = function (nomeWidget) {
		var widget = templateManager.container.getWidget(nomeWidget);
		widget.reload();
	};

	this.removeTransportadora = function(widget) {
		
		var row = widget.currentRow;
		
		Ger01100_Transportadora_Service.removerMascaras(row);
		
		General.callRestEngine('/removeTransportadora', 'Row', row).then(
			
			function(sucess) {
				
				ScreenService.goBack();
				
				widget.reload();
				
				ScreenService.showMessage(sucess.notifications[0].message);
				
			},
			
			function(fail) {
				
				ScreenService.showMessage(fail);
				
			}
			
			);
		
	};

	this.validarCepEnd = function (args) {

		var widget = args.owner.owner.widget;
		var CEP = widget.currentRow.NRCEPTRAN;
		if (CEP) {
			Endereco.buscarCep(CEP).then(function (response) {
				var endereco = response.dataset.ENDERECO;
				if (endereco) {
					widget.currentRow.NRCEPTRAN = CEP;
					widget.currentRow.ENDERECOPARCEIRO = (endereco.DSENDERECO) ? endereco.DSENDERECO : '';
					widget.currentRow.CDPAIS = (endereco.CDPAIS) ? endereco.CDPAIS : '';
					widget.currentRow.NMPAIS = (endereco.NMPAIS) ? endereco.NMPAIS : '';
					widget.currentRow.SGESTADO = (endereco.SGESTADO) ? endereco.SGESTADO : '';
					widget.currentRow.NMESTADO = (endereco.NMESTADO) ? endereco.NMESTADO : '';
					widget.currentRow.CDMUNICIPIO = (endereco.CDMUNICIPIO) ? endereco.CDMUNICIPIO : '';
					widget.currentRow.NMMUNICIPIO = (endereco.NMMUNICIPIO) ? endereco.NMMUNICIPIO : '';
					widget.currentRow.NMBAIRTRAN =   (endereco.NMBAIRRO.slice(0, 29)) ? endereco.NMBAIRRO.slice(0, 29) : '';
					widget.currentRow.CDLOGRADOURO = (endereco.CDLOGRADOURO) ? endereco.CDLOGRADOURO : '';
					widget.currentRow.CDBAIRRO = (endereco.CDBAIRRO) ? endereco.CDBAIRRO : '';
					widget.currentRow.DSENDETRAN = ((endereco.DSLOGRADOURO) ? endereco.DSLOGRADOURO : '') + " " + widget.currentRow.ENDERECOPARCEIRO;
					//widget.currentRow.DSLOGRADOURO = (endereco.DSLOGRADOURO)? endereco.DSLOGRADOURO : '';
					this.controlaVisibilidadeCampoPaisEstadoMunicipioBairro('gridTransportadora');
				}
				if (response.dataset.ERRO){ 
					ScreenService.showMessage(response.dataset.ERRO.MESSAGE, "warning");
				}
			}.bind(this), function(error){
				ScreenService.showMessage("Ouve um erro ao tentar localizar este CEP. Insira um CEP Valido.", "warning");	
			});
		}
		
		widget.redraw();
		widget.reload();
	};

	/* **************************************************
	 * Procedimento que checa o input de inscrição,
	 * validando-o e colocando o tipo de inscrição na
	 * currentRow de acordo.
	 *
	 * Nota: Esse método pressupõe que o input de
	 * inscrição possui as propriedades valueField e
	 * descriptionField, apesar de ser do template
	 * text-edit. Ele também supõe que o valueField
	 * e o descriptionField estarão na currentRow.
	 *
	 * @param Field field
	 */
	this.checkNumeroDeInscricao = function (field) {
		var validatedInscricao = Ger01100_Transportadora_Service.validateNumeroDeInscricao(field.widget.currentRow[field.descriptionField]);
		var widget = field.widget;

		if (validatedInscricao.valid) {
			//if input is valid, builds unformatted data to save
			switch (validatedInscricao.tipo.cod) {
			case 'O': //Código genérico
				validatedInscricao.rawValue = General.fill(validatedInscricao.parameter, 5);
				break;
			case 'I': //Inscrição genérica
				validatedInscricao.rawValue = General.fill(validatedInscricao.parameter, 20);
				break;
			default: //CPF && CNPJ
				validatedInscricao.rawValue = validatedInscricao.parameter;
			}

			//sets data in the currentRow
			widget.currentRow.IDTPIJURTRAN = validatedInscricao.tipo.cod;
			widget.currentRow[field.valueField] = validatedInscricao.rawValue;
			widget.currentRow[field.descriptionField] = validatedInscricao.value;
		} else {
			//if message exists, throws warning popup
			if (validatedInscricao.error.msg)
				ScreenService.showMessage(validatedInscricao.error.msg, "warning");

			//cleans data
			widget.currentRow[field.valueField] = null;
			widget.currentRow[field.descriptionField] = null;
		}
	};

	this.verificaVeiculo = function (args) {
		var widget = templateManager.container.getWidget('gridTransportadora');
		if((widget.getField('NRINSJURTRAN').value() != '') && (widget.getField('NRINSJURTRAN').value() != null)){
			var veiculo = widget.getField('DSTIPOVEIC');
			var inscricao = widget.getField('NRINSJURTRAN').value();
			veiculo.dataSourceFilter[0].value = inscricao.replace(/[^0-9]/g, '');
			widget.getField('DSTIPOVEIC').reload().then(function (Success) {
				if (veiculo.dataSource.data.length === 0) {
					ScreenService.showMessage('Veículo não cadastrado para a transportadora.');
					//ScreenService.closePopup();
				}
			}, function (callback) {});
		}else{
			ScreenService.showMessage('Informe um CNPJ válido.');
		}
	};

	this.salvarTransportadora = function (args) {
		var widget = templateManager.container.getWidget('gridTransportadora');
		if (widget.isValid()) {

			widget.currentRow.CDTIPTRANS = widget.currentRow.CDTIPTRANS ? widget.currentRow.CDTIPTRANS : null;
			widget.currentRow.CDVEICPADRAO = widget.currentRow.CDVEICPADRAO ? widget.currentRow.CDVEICPADRAO : null;
			if (!widget.currentRow.CDLOGRADOURO) {
				widget.currentRow.CDLOGRADOURO = null;
			}
			Ger01100_Transportadora_Service.removerMascaras(widget.currentRow);
			Ger01100_Transportadora_Service.salvarTransportadora(widget.currentRow).then(function (Success) {
				widget.dataSource.name = 'cadExp#/crud/transport_completa';
				if (widget.currentRow.__is_new) {
					widget.list(true);
					ScreenService.goBack();
					widget.reload();
				} else {
					widget.view();
				}
			}, function (callback) {
				if (callback.data) {
					ScreenService.showMessage(callback.data.error);
				}
				widget.dataSource.name = 'cadExp#/crud/transport_completa';

			});
		}
	};
	
	this.verficaParceiro = function (args) {
		var widget = args.owner.owner.widget;
		if (widget.currentRow.NRINSJURTRAN) {
			widget.currentRow.INSCRICAO = widget.currentRow.NRINSJURTRAN.replace(/[^0-9]/g, '');
			Ger01100_Transportadora_Service.buscarParceiro(widget.currentRow).then(function (response) {
					var parceiro = response.dataset.parcnegocio;
					if (parceiro.length !== 0) {
						ScreenService.confirmMessage('Já existe um parceiro para este número de inscrição. Deseja carregar dados do parceiro?', 'question', function (success) {
							widget.currentRow.NMRAZSOCTRAN = parceiro[0].NMPRINCIPALPARC;
							widget.currentRow.NMFANTTRAN = parceiro[0].NMSECUNDARIPARC;
							widget.currentRow.NRPARCNEGOCIO = parceiro[0].NRPARCNEGOCIO;
						});
					}
				},
				function (callback) {
					if (callback.data) {
						ScreenService.showMessage(callback.data.error);
					}
				});
		}
	};

	this.addMask = function (widget) {
		
		var data = widget.dataSource.data;
		
		if(data[0].NRINSJURTRAN.length <= 14) {
		
			data.forEach(function (element, index, data) {
				if (element.NRINSJURTRAN.length == 14)
					element.NRINSJURTRAN = element.NRINSJURTRAN.replace(/^(\d{2})(\d{3})(\d{3})(\d{4})(\d{2})/, "$1.$2.$3/$4-$5");
				if (element.NRINSJURTRAN.length == 11)
					element.NRINSJURTRAN = element.NRINSJURTRAN.replace(/^(\d{3})(\d{3})(\d{3})(\d{2})/, "$1.$2.$3-$4");
			});
			
		widget.redraw();
		
		} 
		
		
		
	};

};

Configuration(function (ContextRegister) {
	ContextRegister.register('Ger01100_Transportadora_Controller', Ger01100_Transportadora_Controller);
});

// FILE: ./assets/js/controllers/ger02800_motorista_Controller.js
function ger02800_motorista_Controller (ScreenService, General, GeralCE_Utility, templateManager){
    self.ativoLastStatus = 'S';
    
    this.salvarMotorista = function(widget){
        if(widget.isValid()){
            if(widget.currentRow.NRCPF!=undefined)
                widget.currentRow.NRCPF = widget.currentRow.NRCPF.replace(/([.-])/g,"");
            General.saveCrud(widget).then(function(){
                if (widget.isNewRow()) {
                    self.ativoLastStatus = widget.currentRow.IDSITMOT;
                }
            });
        }
    };
    
    this.trocaVisibilidade = function(widget){
        var field = templateManager.container.getWidget('MotoristaWidget').getField('NMAJUDANTE');
        if(widget.currentRow.IDTPMOTORISTA == "A"){
            field.readOnly = true;
            widget.currentRow.NMAJUDANTE = '';
        } else {
            field.readOnly = false;
        }
    };
    
    this.recarregarField = function(nomeWidget, nomeField){
        var field = templateManager.container.getWidget(nomeWidget).getField(nomeField);
        field.reload();
    };
    
    this.onNew = function(widget){
        widget.newRow();
        widget.currentRow.IDSITMOT = self.ativoLastStatus;
        General.justInteger('#CDMOTORISTA');
    };
    
}

Configuration(function(ContextRegister){
    ContextRegister.register('ger02800_motorista_Controller', ger02800_motorista_Controller);
});
