var ZeedhiDirectives = angular.module("ZeedhiDirectives");

ZeedhiDirectives.directive('zhChart', function(templateManager, ScreenService, $timeout, eventEngine, ApplicationContext, $window, $rootScope, maskEngine) {
	return {
		link: function($scope, element, attrs, controller) {
			function getFormat(format) {
				var result;
				switch (format) {
					case "currency": 
						result = (function(value) { return maskEngine.currencyFormat(value); });
						break;
					case "float":
						result = (function(value) { return maskEngine.floatFormat(value); });
						break;
					case "percent":
						result = (function(value) { return maskEngine.percentFormat(value); });
						break;
					case "number":
						result = (function(value) { return maskEngine.numberFormat(value); });
						break;
					case "metric":
						result = (function(value) { return maskEngine.metricFormat(value); });
						break;
					default:
						result = format;
				}

				return result;
			}

			var widget = $scope.widget;

			// Floating Control defaults
			var floatingControlDefaults = {
				position: "top right"
			};
			widget.floatingControl = widget.floatingControl !== false && Util.extend(floatingControlDefaults, widget.floatingControl || {});

			var options;
			function buildOptions(widget) {
				var opt = {
					title: widget.chartTitle || false,
					subtitle: widget.chartSubTitle || false,
					fontName: "open_sanslight, Helvetica, Arial, sans-serif",
					dataSource: {
						data: widget.dataSource.data
					},
					showTooltip: widget.chartShowTooltip,
					showValueLabels: widget.chartShowValueLabels,
					showDrillUpButton: widget.chartShowDrillUpButton,
					xAxis: {
						field: widget.chartXAxisField,
						position: widget.chartXAxisPosition,
						bandDimensions: {
							type: widget.chartXAxisBandDimensionType,
							minWidth: widget.chartXAxisBandDimensionMinWidth,
							gap: widget.chartXAxisBandDimensionGap
						},
						ticks: {
							maxWidth: widget.chartXAxisTicksMaxWidth,
							maxLines: widget.chartXAxisTicksMaxLines,
							rotation: widget.chartXAxisTicksRotation
						},
						format: getFormat(widget.chartXAxisFormat)
					},
					legend: {
						position: widget.chartLegendPosition,
						margin: widget.chartLegendMargin,
						visible: widget.chartLegendVisible,
						closed: widget.chartLegendClosed
					},
					series: [],
					invertedAxes: widget.chartInvertedAxes,
					events: {
						onDataClick: dataClick,
						onFinishDrawing: finishDrawing
					}
				};

				var serie;
				for (var i = 0; i < widget.chartSeries.length; i++) {
					serie = {
						// all series
						type: widget.chartSeries[i].serieType,
						colors: widget.chartSeries[i].serieColors,
						showValueLabels: widget.chartSeries[i].serieShowValueLabels,
						// bar, line and area
						fields: widget.chartSeries[i].serieFields,
						labels: widget.chartSeries[i].serieLabels,
						yAxis: {
							label: widget.chartSeries[i].serieYAxisLabel,
							position: widget.chartSeries[i].serieYAxisPosition,
							showGridLines: widget.chartSeries[i].serieYAxisShowGridLines,
							range: widget.chartSeries[i].serieYAxisRange,
							formatName: widget.chartSeries[i].serieYAxisFormat,
							format: getFormat(widget.chartSeries[i].serieYAxisFormat),
							linkedSerie: widget.chartSeries[i].serieYAxisLinkedSerie
						},
						stacked: widget.chartSeries[i].serieStacked,
						// bar
						floating: widget.chartSeries[i].serieFloating,
						floatingGap: widget.chartSeries[i].serieFloatingGap,
						maxBarWidth: widget.chartSeries[i].serieMaxBarWidth,
						colorExpression: widget.chartSeries[i].serieColorExpression,
						// line and area
						lineType: widget.chartSeries[i].serieLineType,
						lineWidth: widget.chartSeries[i].serieLineWidth,
						marks: {
							type: widget.chartSeries[i].serieLineMarkType,
							size: widget.chartSeries[i].serieLineMarkSize
						},
						// area
						areaOpacity: widget.chartSeries[i].serieAreaOpacity,
						// pie, donut
						sort: widget.chartSeries[i].serieSort,
						fieldLabel: widget.chartSeries[i].serieFieldLabel,
						fieldValue: widget.chartSeries[i].serieFieldValue,
						pivoted: widget.chartSeries[i].seriePivoted,
						pivotedFields: widget.chartSeries[i].seriePivotedFields,
						pivotedLabels: widget.chartSeries[i].seriePivotedLabels,
						// pie, donut and gauge
						strokeWidth: widget.chartSeries[i].serieStrokeWidth,
						strokeColor: widget.chartSeries[i].serieStrokeColor,
						arcsGap: widget.chartSeries[i].serieArcsGap,
						// pie, donut, gauge and progress
						valueFormat: getFormat(widget.chartSeries[i].serieValueFormat),
						// donut
						donutWidth: widget.chartSeries[i].serieDonutWidth,
						// gauge
						rangeType: widget.chartSeries[i].serieRangeType,
						ranges: widget.chartSeries[i].serieRanges,
						gaugeWidth: widget.chartSeries[i].serieGaugeWidth,
						pointerColor: widget.chartSeries[i].seriePointerColor,
						showGaugeValue: widget.chartSeries[i].serieShowGaugeValue,
						// gauge and progress
						horizontal: widget.chartSeries[i].serieHorizontal,
						value: widget.chartSeries[i].serieValue,
						maxValue: widget.chartSeries[i].serieMaxValue,
						// progress
						showProgressValue: widget.chartSeries[i].serieShowProgressValue,
						backgroundColor: widget.chartSeries[i].serieProgressBackgroundColor,
						progressWidth: widget.chartSeries[i].serieProgressWidth
					};

					opt.series.push(serie);
				}

				return opt;
			}
			options = buildOptions(widget);

			var chart = widget.chart = zhChart(options);
			if (element.hasClass('zh-dashboard-chart')) {
				$scope.$on("zh-masonry-grid-finished", function(events, el) { 
					if (el[0] == element.parents('[data-zh-masonry-grid]')[0] && element.is(":visible")) {
						$timeout(function() {
							if (Util.isUndefined(element[0]._chart)) {
								chart.dataSourceData(widget.dataSource.data)(element[0]); 
							} else {
								element[0]._chart.redraw();
							}
						});
					}
				});
			} else {
				$scope.$on("zh-scrolled-finished", function(events, el) { 
					if (el[0] == element.parent()[0] && element.is(":visible")) {
						$timeout(function() {
							chart.dataSourceData(widget.dataSource.data)(element[0]); 
						});
					}
				});
			}

			$scope.$watchCollection("widget.dataSource.data", function(newValue) {
				if (element.is(":visible")) {
					chart.dataSourceData(newValue).updateSeries();
				}
			});

			if (widget) {
				var events = widget.events;
				if (events) {
					eventEngine.bindEvents(
						element,
						events,
						function() {
							if (widget.dataSource) {
								return widget.dataSource.data;
							}
						},
						function() {
							return widget.currentRow;
						},
						function() {
							return widget.selectedRow;
						}
					);
				}
			}

			function dataClick(event, data) {
				if (widget) { 
					widget.setCurrentRow(data); 
				}
			}

			function finishDrawing() {
				if (widget && widget.chartFinishDrawing) { 
					widget.chartFinishDrawing(null, {data: {element: element}}); 
				}
			}

			$scope.saveChartAsSVG = function() {
				chart.saveSVG();
			};

			$scope.saveChartAsPNG = function() {
				chart.savePNG();
			};

			var floatingControl = element.parent().find(".zh-floating-control");
			var button;

			if (widget.chartShowValueLabels === false) {
				button = floatingControl.find("li.show-labels-action");
				button.addClass("disabled");
			}

			$scope.toggleValueLabels = function() {
				var li = floatingControl.find("li.show-labels-action");
				li.toggleClass("disabled");
				chart.toggleValueLabels(!li.hasClass("disabled"));
			};			

			if (widget.chartShowTooltip === false) {
				button = floatingControl.find("li.show-tooltip");
				button.addClass("disabled");
			}

			$scope.toggleTooltip = function() {
				var li = floatingControl.find("li.show-tooltip");
				li.toggleClass("disabled");
				chart.toggleTooltip(!li.hasClass("disabled"));
			};

			if (widget.chartLegendVisible === false) {
				button = floatingControl.find("li.show-legend");
				button.addClass("disabled");
			}

			$scope.toggleLegend = function() {
				var li = floatingControl.find("li.show-legend");
				li.toggleClass("disabled");
				chart.toggleLegend(!li.hasClass("disabled"));
			};

			widget.updateChart = function() {
				var options = buildOptions(this);
				if (widget.chart) {
					widget.chart.updateChart(options);
				}
			};
		}
	};
});

Configuration(function (ContextRegister, eventEngine) {
	// register the event finishDrawingEvent
	eventEngine.registerEvent('WidgetOnChartFinishDrawing', 'chartFinishDrawing');
});